# Generated by Django 5.1.2 on 2024-10-17 17:19

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sage_invoice", "0002_alter_invoice_template_choice"),
    ]

    operations = [
        migrations.AlterField(
            model_name="expense",
            name="invoice",
            field=models.OneToOneField(
                db_comment="Reference to the associated invoice",
                help_text="The invoice associated with this total.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="expense",
                to="sage_invoice.invoice",
                verbose_name="Invoice",
            ),
        ),
        migrations.AlterField(
            model_name="invoice",
            name="category",
            field=models.ForeignKey(
                blank=True,
                db_comment="Category associated with this invoice",
                help_text="The category associated with this invoice.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="invoices",
                to="sage_invoice.category",
                verbose_name="Category",
            ),
        ),
        migrations.AlterField(
            model_name="item",
            name="quantity",
            field=models.PositiveIntegerField(
                blank=True,
                db_comment="The quantity of the invoice item",
                help_text="The quantity of the item.",
                null=True,
                verbose_name="Quantity",
            ),
        ),
    ]
