# Generated by Django 5.1.2 on 2024-10-17 09:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sage_invoice", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="template_choice",
            field=models.CharField(
                choices=[
                    ("quotation_1", "quotation_1"),
                    ("quotation_2", "quotation_2"),
                    ("quotation_3", "quotation_3"),
                    ("quotation_4", "quotation_4"),
                    ("receipt1", "receipt1"),
                    ("receipt2", "receipt2"),
                    ("receipt3", "receipt3"),
                ],
                db_comment="Template choice for the invoice",
                help_text="The template you want for your invoice",
                max_length=20,
                verbose_name="Template choice",
            ),
        ),
    ]
